
# Astro Radio Workstation Setup

A complete bash setup script for turning a Linux workstation into a powerful scientific and radio astronomy platform.

## 🔧 Features

- General scientific + plotting libraries
- Astronomy & radio astronomy software
- SDR + waterfall/audio tools
- SETI & RTL-SDR support
- Monitoring & Docker
- Flatpak support

## 🚀 Setup

```bash
chmod +x astro_radio_full_setup.sh
./astro_radio_full_setup.sh
```

## 🐳 Docker Image (RTL-SDR v3/v4 Compatible)

### Build locally

```bash
docker build -t astro-radio-docker .
```

### Run

```bash
docker run -it --rm --device /dev/bus/usb -p 8888:8888 astro-radio-docker
```

Then open `http://localhost:8888` in your browser for JupyterLab.

---

## 📡 RTL-SDR Notes

This system is tuned for:
- RTL-SDR v3
- RTL-SDR v4

For full RTL-SDR device support, ensure you’re in the `plugdev` group and udev rules are installed.

## 🧪 Included Notebooks

You’ll find example notebooks for:
- SDR spectrum and waterfall analysis
- I/Q data plotting
- Sky maps and signal tracking

---

MIT License
