#!/bin/bash

echo "=== [1/10] Updating system and installing core utilities ==="
sudo apt update && sudo apt install -y \
    build-essential \
    gfortran \
    cmake \
    git \
    curl \
    wget \
    unzip \
    screen \
    tmux \
    htop \
    vim \
    net-tools \
    lsb-release \
    software-properties-common \
    gnupg \
    ca-certificates \
    apt-transport-https

echo "=== [2/10] Installing scientific libraries ==="
sudo apt install -y \
    libfftw3-dev \
    libblas-dev \
    liblapack-dev \
    libopenblas-dev \
    libgsl-dev \
    libhdf5-dev \
    libnetcdf-dev \
    libpng-dev \
    libjpeg-dev \
    libtiff-dev \
    libx11-dev \
    libxml2-dev \
    libgl1-mesa-dev \
    libboost-all-dev \
    libeigen3-dev

echo "=== [3/10] Installing Python environment and scientific packages ==="
sudo apt install -y \
    python3 \
    python3-pip \
    python3-venv \
    ipython3 \
    jupyter-notebook

pip3 install --upgrade pip
pip3 install \
    numpy \
    scipy \
    matplotlib \
    pandas \
    seaborn \
    sympy \
    scikit-learn \
    h5py \
    jupyterlab \
    astropy \
    astroquery \
    sunpy \
    healpy \
    kapteyn \
    skyfield

echo "=== [4/10] Installing astronomy GUI applications ==="
sudo apt install -y \
    kstars \
    gpredict \
    virtualplanet \
    nova \
    stellarium \
    saods9 \
    xephem

echo "=== [5/10] Installing radio astronomy and SDR tools ==="
sudo apt install -y \
    gnuradio \
    gqrx-sdr \
    rtl-sdr \
    libvolk2-dev \
    baudline \
    sox \
    sox-fmt-all \
    fldigi

# Optional GNU Radio plugins (example)
sudo apt install -y gr-osmosdr

echo "=== [6/10] Installing waterfall and audio visualization tools ==="
sudo apt install -y \
    audacity \
    qspectrumanalyzer \
    pulseaudio-utils \
    pavucontrol

echo "=== [7/10] Installing SETI and related tools ==="

# SETI@home (now volunteer-based only; this is BOINC installer)
sudo apt install -y boinc-client boinc-manager

# Additional amateur radio/astronomy tools from repositories
sudo apt install -y predict

echo "=== [8/10] System monitoring and logging tools ==="
sudo apt install -y \
    conky \
    glances \
    iotop \
    nmon \
    sysstat

echo "=== [9/10] Installing Docker for reproducible environments ==="
sudo apt install -y docker.io
sudo systemctl enable docker --now
sudo usermod -aG docker $USER

echo "=== [10/10] Installing Octave, Gnuplot, HDF viewers ==="
sudo apt install -y \
    octave \
    gnuplot \
    hdfview \
    gsl-bin

echo "=== [Optional] Adding Flatpak and Flathub ==="
sudo apt install -y flatpak gnome-software-plugin-flatpak
flatpak remote-add --if-not-exists flathub https://flathub.org/repo/flathub.flatpakrepo

echo "=== SETUP COMPLETE ==="
echo "Log out and back in to complete Docker group activation."
